@rem IBM Cognos 8 Special Edition - IBM Oracle Configuration Script
@rem Copyright (C) 2008 Cognos ULC, an IBM Company. All rights reserved. 
@rem Cognos (R) is a trademark of Cognos ULC, (formerly Cognos Incorporated).
@echo off

@rem Setup common environment variables
set C8SE_scripts=%~dp0%

@rem Vega settings
set C8SE_WAS_Dst=[VEGA_WAS_Dst]
set C8SE_C8_Dst=[VEGA_C8_Dst]
set JAVA_HOME=%C8SE_WAS_Dst%\java
set C8SE_ORACLE_Dst=[ORACLE_HOME]

@rem Set the log file name if not already set
if NOT DEFINED C8SE_logfile (
  set C8SE_logfile=%C8SE_scripts%C8SE_install.log
)

@rem Locate and set JAVA_HOME
if EXIST "%C8SE_WAS_Dst%\bin\setupCmdLine.bat" (
  call "%C8SE_WAS_Dst%\bin\setupCmdLine.bat"
)
if NOT DEFINED JAVA_HOME (
  if EXIST "%C8SE_C8_Dst%%C8SE_C8_JRE%" (
    set JAVA_HOME=%C8SE_C8_Dst%%C8SE_C8_JRE%
  )
)
if NOT DEFINED JAVA_HOME (
  @echo %DATE% %TIME% FATAL: Unable to locate a suitable Java Runtime>>"%C8SE_logfile%"
  @echo FATAL: Unable to locate a suitable Java Runtime
  goto exit 
)
if EXIST "%JAVA_HOME%\bin\java.exe" (
  set _JAVACMD=%JAVA_HOME%\bin\java.exe
) else (
  if EXIST "%JAVA_HOME%\jre\bin\java.exe" (
    set _JAVACMD=%JAVA_HOME%\jre\bin\java.exe
  ) else (
    @echo %DATE% %TIME% FATAL: Unable to locate a suitable Java Runtime executable>>"%C8SE_logfile%"
    @echo FATAL: Unable to locate a suitable Java Runtime executable
    goto exit 
  )
)
@echo %DATE% %TIME% INFO: Using Java Runtime found in %JAVA_HOME%>>"%C8SE_logfile%"

if NOT EXIST "%C8SE_C8_Dst%\configuration\cogstartup.xml" (
  @echo %DATE% %TIME% FATAL: File %C8SE_C8_Dst%\configuration\cogstartup.xml could not be located>>"%C8SE_logfile%"
  @echo FATAL: File %C8SE_C8_Dst%\configuration\cogstartup.xml could not be located
  goto exit 
)

@rem Backup the existing configuration file if a backup does not already exist
if NOT EXIST "%C8SE_C8_Dst%\configuration\cogstartup.xml.backup" (
  @echo %DATE% %TIME% INFO: Backing up file %C8SE_C8_Dst%\configuration\cogstartup.xml>>"%C8SE_logfile%"
  copy /y "%C8SE_C8_Dst%\configuration\cogstartup.xml" "%C8SE_C8_Dst%\configuration\cogstartup.xml.backup" >>"%C8SE_logfile%" 2>>&1
)
@rem Verify the backup file is in place
if NOT EXIST "%C8SE_C8_Dst%\configuration\cogstartup.xml.backup" (
  @echo %DATE% %TIME% FATAL: File %C8SE_C8_Dst%\configuration\cogstartup.xml.backup could not be created>>"%C8SE_logfile%"
  @echo FATAL: File %C8SE_C8_Dst%\configuration\cogstartup.xml.backup could not be created
  goto exit 
)

@rem Generate a new cogstartup.xml for Oracle using a transformation

@rem Setup the classpath to point to the Jar files we need for running the transformation on the cogstartup.xml file
@echo %DATE% %TIME% INFO: Setting transform classpath>>"%C8SE_logfile%"
if EXIST "%C8SE_C8_Dst%\webapps\p2pd\WEB-INF\lib" (
set _CLASSPATH=%C8SE_C8_Dst%\webapps\p2pd\WEB-INF\lib\jdxslt.jar;%C8SE_C8_Dst%\webapps\p2pd\WEB-INF\lib\xercesImpl.jar;%C8SE_C8_Dst%\webapps\p2pd\WEB-INF\lib\xml-apis.jar
)

@rem Setup some variables that will be used in the transformation on the cogstartup.xml file
set _SOURCEXML=%C8SE_C8_Dst%\configuration\cogstartup.xml
set _TARGETXML=%C8SE_C8_Dst%\configuration\cogstartup.C8SE.xml
@echo %DATE% %TIME% INFO: Setting source (%_SOURCEXML%) and target (%_TARGETXML%) for transform>>"%C8SE_logfile%"

@rem Use the C8SE_Config_Oracle.xslt transformation to replace the Content Store database section of the startup file
@echo %DATE% %TIME% INFO: Running xslt transformation command>>"%C8SE_logfile%"
@echo %DATE% %TIME% INFO: Java Command: "%_JAVACMD%" -cp "%_CLASSPATH%" jd.xml.xslt.Stylesheet -OUT "%_TARGETXML%" "%_SOURCEXML%" "%C8SE_scripts%C8SE_Config_Oracle.xslt">>"%C8SE_logfile%"

"%_JAVACMD%" -cp "%_CLASSPATH%" jd.xml.xslt.Stylesheet -OUT "%_TARGETXML%" "%_SOURCEXML%" "%C8SE_scripts%C8SE_config_Oracle.xslt">>"%C8SE_logfile%" 2>>&1

@rem Save the original cogstartup file and replace with the new one that was transformed
@echo %DATE% %TIME% INFO: Renaming of cogstartup.xml file after transformation>>"%C8SE_logfile%"
if EXIST "%_SOURCEXML%" (
  @echo %DATE% %TIME% INFO: Creating a backup of %_SOURCEXML%>>"%C8SE_logfile%"
  copy /y "%_SOURCEXML%" "%C8SE_C8_Dst%\configuration\cogstartup.backup.xml" >>"%C8SE_logfile%" 2>>&1
) else (
  @echo %DATE% %TIME% FATAL: File %_SOURCEXML% could not be located>>"%C8SE_logfile%"
  @echo FATAL: Source file %_SOURCEXML% could not be located
  goto exit
)
if EXIST "%C8SE_C8_Dst%\configuration\cogstartup.backup.xml" (
  if EXIST "%_TARGETXML%" (
    @echo %DATE% %TIME% INFO: Replacing %_SOURCEXML% with %_TARGETXML%>>"%C8SE_logfile%"
    copy /y "%_TARGETXML%" "%_SOURCEXML%" >>"%C8SE_logfile%" 2>>&1
  ) else (
    @echo %DATE% %TIME% FATAL: File %_TARGETXML% could not be located>>"%C8SE_logfile%"
    @echo FATAL: Target file %_TARGETXML% could not be located
    goto exit
  )
)

@rem Verify cogstartup.xml is in place after manipulation
if NOT EXIST "%C8SE_C8_Dst%\configuration\cogstartup.xml" (
  @echo %DATE% %TIME% FATAL: File %C8SE_C8_Dst%\configuration\cogstartup.xml could not be located>>"%C8SE_logfile%"
  @echo FATAL: File %C8SE_C8_Dst%\configuration\cogstartup.xml could not be located
  goto exit 
)

@rem Copy the Oracle JDBC Driver to the proper location
if EXIST "%C8SE_C8_Dst%\webapps\p2pd\WEB-INF\lib" (
  if EXIST "%C8SE_ORACLE_Dst%\jdbc\lib\ojdbc5.jar" (
    @echo %DATE% %TIME% INFO: %C8SE_DB2_Version%: Copy ojdbc5.jar to the web applications folder>>"%C8SE_logfile%"
    copy /y "%C8SE_ORACLE_Dst%\jdbc\lib\ojdbc5.jar" "%C8SE_C8_Dst%\webapps\p2pd\WEB-INF\lib\ojdbc5.jar" >>"%C8SE_logfile%" 2>>&1
  )
  if EXIST "%C8SE_ORACLE_Dst%\jdbc\lib\ojdbc14.jar" (
    @echo %DATE% %TIME% INFO: %C8SE_DB2_Version%: Copy ojdbc14.jar to the web applications folder>>"%C8SE_logfile%"
    copy /y "%C8SE_ORACLE_Dst%\jdbc\lib\ojdbc14.jar" "%C8SE_C8_Dst%\webapps\p2pd\WEB-INF\lib\ojdbc14.jar" >>"%C8SE_logfile%" 2>>&1
  )
  if EXIST "%C8SE_C8_Dst%\webapps\p2pd\WEB-INF\lib\classes12.jar" (
	@echo %DATE% %TIME% INFO: %C8SE_C8_Version%: Deleting "%C8SE_C8_Dst%\webapps\p2pd\WEB-INF\lib\classes12.jar" file>>"%C8SE_logfile%"
	del /q "%C8SE_C8_Dst%\webapps\p2pd\WEB-INF\lib\classes12.jar" >>"%C8SE_logfile%" 2>>&1
  )
)
if NOT EXIST "%C8SE_C8_Dst%\webapps\p2pd\WEB-INF\lib\ojdbc14.jar" (
  if NOT EXIST "%C8SE_C8_Dst%\webapps\p2pd\WEB-INF\lib\ojdbc5.jar" (
    @echo %DATE% %TIME% FATAL: %C8SE_DB2_Version%: Unable to create or copy %C8SE_C8_Dst%\webapps\p2pd\WEB-INF\lib\ojdbc14.jar or %C8SE_C8_Dst%\webapps\p2pd\WEB-INF\lib\ojdbc5.jar>>"%C8SE_logfile%"
    @echo FATAL: %C8SE_DB2_Version%: Unable to create %C8SE_C8_Dst%\webapps\p2pd\WEB-INF\lib\ojdbc14.jar or %C8SE_C8_Dst%\webapps\p2pd\WEB-INF\lib\ojdbc5.jar
    goto exit
  ) 
)


:exit
@rem Return to original location
@echo %DATE% %TIME% INFO: Changing directories to %C8SE_scripts%>>"%C8SE_logfile%"
cd /d %C8SE_scripts%

@echo %DATE% %TIME% INFO: Exiting IBM Oracle WSE configuration script>>"%C8SE_logfile%"

@rem *****************
@rem * End of Script *
@rem *****************